summaryrefslogtreecommitdiffstats
path: root/win/CS/HandBrake.Interop/HandBrakeInterop/SourceData/Title.cs
diff options
context:
space:
mode:
authorrandomengy <[email protected]>2013-03-31 20:55:00 +0000
committerrandomengy <[email protected]>2013-03-31 20:55:00 +0000
commitb37e7f1b4078fa478424a80fbaf1f56639e50eaa (patch)
treee0f9e61f67ebc56bd0258f000243c40ec12eb8fe /win/CS/HandBrake.Interop/HandBrakeInterop/SourceData/Title.cs
parent09e3a53c02d90e793885983a384a9283b8243590 (diff)
Exposing DurationPts on titles and chapters from scans, along with some conversion functions.
Adding values to ScanProgressEventArgs to expose more fine-tuned progress. Updating structs to catch up to most recent HB SVN. Added a new VideoRangeType: All. This allows you to specify an entire title to convert without counting chapters. We now create the filter list sorted and pass in the RENDERSUB filter with correct cropping values. This fixes burned-in subtitles getting cut off by cropping. git-svn-id: svn://svn.handbrake.fr/HandBrake/trunk@5369 b64f7644-9d1e-0410-96f1-a4d463321fa5
Diffstat (limited to 'win/CS/HandBrake.Interop/HandBrakeInterop/SourceData/Title.cs')
-rw-r--r--win/CS/HandBrake.Interop/HandBrakeInterop/SourceData/Title.cs7
1 files changed, 6 insertions, 1 deletions
diff --git a/win/CS/HandBrake.Interop/HandBrakeInterop/SourceData/Title.cs b/win/CS/HandBrake.Interop/HandBrakeInterop/SourceData/Title.cs
index 57201e847..8c7d65412 100644
--- a/win/CS/HandBrake.Interop/HandBrakeInterop/SourceData/Title.cs
+++ b/win/CS/HandBrake.Interop/HandBrakeInterop/SourceData/Title.cs
@@ -84,11 +84,16 @@ namespace HandBrake.Interop.SourceData
public int Playlist { get; set; }
/// <summary>
/// Gets or sets the length in time of this Title
/// </summary>
public TimeSpan Duration { get; set; }
/// <summary>
+ /// Gets or sets the duration of the title in PTS.
+ /// </summary>
+ public ulong DurationPts { get; set; }
+
+ /// <summary>
/// Gets or sets the resolution (width/height) of this Title
/// </summary>
public Size Resolution { get; set; }
@@ -84,11 +84,16 @@ namespace HandBrake.Interop.SourceData
public int Playlist { get; set; }
/// <summary>
- /// Gets or sets the length in time of this Title
+ /// Gets or sets the duration of this title.
/// </summary>
public TimeSpan Duration { get; set; }